[![NPM version](https://badge.fury.io/js/cdk-serverless-api.svg)](https://badge.fury.io/js/cdk-serverless-api)
[![PyPI version](https://badge.fury.io/py/cdk-serverless-api.svg)](https://badge.fury.io/py/cdk-serverless-api)
![Release](https://github.com/pahud/serverless-api-demo/workflows/Release/badge.svg)

# Welcome to `cdk-serverless-api`

This sample construct library helps you build Serverless API in AWS.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
from cdk_serverless_api import ServerlessApi

ServerlessApi(self, "Api")
```
